Package: savR
Type: Package
Title: Parse and analyze Illumina SAV files
Version: 1.28.0
Date: 2015-07-28
Author: R. Brent Calder
Maintainer: R. Brent Calder <brent.calder@einstein.yu.edu>
Description: Parse Illumina Sequence Analysis Viewer (SAV) files,
    access data, and generate QC plots.
License: AGPL-3
URL: https://github.com/bcalder/savR
BugReports: https://github.com/bcalder/savR/issues
Depends: ggplot2
Imports: methods, reshape2, scales, gridExtra, XML
Suggests: Cairo, testthat
biocViews: Sequencing
git_url: https://git.bioconductor.org/packages/savR
git_branch: RELEASE_3_12
git_last_commit: b051b0b
git_last_commit_date: 2020-10-27
Date/Publication: 2020-10-27
NeedsCompilation: no
Packaged: 2020-10-28 03:08:14 UTC; biocbuild
